#ifdef QT4

#else
#include <qgrid.h>
#endif

#include <qgroupbox.h>
#include <qlayout.h>
#include <qlabel.h>
#include <qlineedit.h>

#include "qscrobblerconfig.h"
#include "qscrobbleraddon.h"

/* QScrobblerConfiguration */

QScrobblerConfiguration::QScrobblerConfiguration()
{
    username_ = "";
    md5Password_ = "";
    cacheSaveInterval_ = 20;
    submissionPaused_ = false;
}

void QScrobblerConfiguration::write(Config &cf) const
{
    cf.setGroup("QScrobbler");
    cf.writeEntry("username", username_);
    cf.writeEntry("password", md5Password_);
    cf.writeEntry("cacheSaveInterval", cacheSaveInterval_);
    cf.writeEntry("submissionPaused", submissionPaused_);
}

void QScrobblerConfiguration::read(Config &cf)
{
    cf.setGroup("QScrobbler");
    username_ = cf.readEntry("username", "");
    md5Password_ = cf.readEntry("password", "");
    cacheSaveInterval_ = cf.readNumEntry("cacheSaveInterval", 20);
    submissionPaused_ = cf.readBoolEntry("submissionPaused", false);
}

/* QScrobblerConfig */

QScrobblerConfig::QScrobblerConfig(Configuration& configuration, QWidget *parent)
    : ConfigView(configuration, parent)
{
}

void QScrobblerConfig::createWidgets()
{
    ConfigView::createWidgets();

    QVBoxLayout *layout = new QVBoxLayout(widget());
    layout->setSpacing(4);
#ifdef QT4
    layout->setAlignment(Qt::AlignTop);
#endif

    // Account data information
    QGroupBox *accountDataBox = new QGroupBox(tr("Account"), widget());
    layout->addWidget(accountDataBox);

    QGridLayout *accountDataBoxLayout = new QGridLayout(accountDataBox);
    accountDataBoxLayout->setSpacing(5);
    accountDataBoxLayout->setMargin(5);

    QLabel *lbUsername = new QLabel(tr("Username:"), accountDataBox);
    leUsername = new QLineEdit(accountDataBox);

    QLabel *lbPassword = new QLabel(tr("Password:"), accountDataBox);
    lePassword = new QLineEdit(accountDataBox);
    lePassword->setEchoMode(QLineEdit::Password);

    accountDataBoxLayout->addWidget(lbUsername, 0, 0);
    accountDataBoxLayout->addWidget(leUsername, 0, 1);

    accountDataBoxLayout->addWidget(lbPassword, 1, 0);
    accountDataBoxLayout->addWidget(lePassword, 1, 1);
}

void QScrobblerConfig::setStatesByConfiguration(const Configuration& config)
{
    ConfigView::setStatesByConfiguration(config);

    leUsername->setText(qScrobblerAddOn.config().username());
    lePassword->setText(qScrobblerAddOn.config().md5Password());
}

void QScrobblerConfig::saveStatesToConfiguration()
{
    ConfigView::saveStatesToConfiguration();

    qScrobblerAddOn.config().setUsername(leUsername->text());

    if (lePassword->text() != qScrobblerAddOn.config().md5Password())
        qScrobblerAddOn.config().setPassword(lePassword->text());
}
