#ifndef PLAYLISTASPECTOVERVIEWMODEL_H
#define PLAYLISTASPECTOVERVIEWMODEL_H

#include <QAbstractListModel>
#include <QItemSelectionModel>
#include "playlistaspectoverviewfilter.h"

class PlayListAspectOverviewModel: public QAbstractListModel
{
    Q_OBJECT
public:
    PlayListAspectOverviewModel(PlayListAspectOverviewFilter *aspect, const QString &roleName, OverviewFilterList *list);

    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    int columnCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const;

    void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);

public slots:
    void rereadData();

private:
    friend class PlayListAspectOverviewFilter;
    friend class PlayListAspectOverviewSelectionModel;
    PlayListAspectOverviewFilter *aspect_;
    QString roleName_;
    OverviewFilterList *list_;
};

class PlayListAspectOverviewSelectionModel: public QItemSelectionModel
{
    Q_OBJECT
public:
    PlayListAspectOverviewSelectionModel(PlayListAspectOverviewModel *model);

public slots:
    virtual void clear();
    virtual void reset();
    virtual void select(const QModelIndex &selection, QItemSelectionModel::SelectionFlags command);
    virtual void select(const QItemSelection &selection, QItemSelectionModel::SelectionFlags command);

    void transferSelectionFromList();

signals:
    void listUpdateRequired();

private:
    friend class PlayListAspectOverviewModel;
    PlayListAspectOverviewModel *model_;
    bool updating_;
    bool selecting_;

    void transferSelectionToList();
};

#endif // PLAYLISTASPECTOVERVIEWMODEL_H
